<?xml version="1.0" ?>

<!-- style sheet for mySite -->
<!-- Copyright 2002-2024 Dr. Thomas Redelberger, redetho@gmx.de -->

<!--
$Id: trWSite.xsl 1.3 2024/05/31 10:40:26 redetho Exp redetho $
-->

<!DOCTYPE xsl:stylesheet [
<!ENTITY nbsp "&#160;">
<!ENTITY copy "&#169;">
]>
<xsl:stylesheet	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="xml" encoding="UTF-8" omit-xml-declaration="yes"/>

<!-- gives: !DOCTYPE html SYSTEM "html" which is not what it is supposed to be hence see below
	<xsl:output method="xml" encoding="UTF-8" doctype-system="html" omit-xml-declaration="yes"/>
-->
<!-- obsolete
	<xsl:output method="html" doctype-system="http://www.w3.org/TR/html4/strict.dtd" doctype-public="-//W3C//DTD HTML 4.01//EN" encoding="iso-8859-1"/>
-->

	<!-- ****************** Parameters for this stylesheet ***************** -->

	<xsl:param    name="mySrcDoc"     select="'body.htm'"/>		<!-- default source file name -->
	<xsl:param    name="myISODT"      select="'20021118120000'"/>		<!-- default update date/time -->
	<xsl:param    name="myISOTodayDT" select="'20240101120000'"/>		<!-- default calendar date/time -->

	<xsl:param    name="myDstDoc"     select="'index.htm'"/>	<!-- default destination file name -->
	<xsl:param    name="myCSSDoc"     select="'client.css'"/>	<!-- default CSS file name -->


	<!-- ******************* Constants for this stylesheet ***************** -->

	<xsl:variable name="myYear"       select="substring($myISODT,1,4)"/>	<!-- just for convenience -->
	<xsl:variable name="myMonth"      select="substring($myISODT,5,2)"/>
	<xsl:variable name="myDay"        select="substring($myISODT,7,2)"/>
	<xsl:variable name="myTodayYear"  select="substring($myISOTodayDT,1,4)"/>


<!-- site specific stuff following -->
<!-- Teutsch
	<xsl:variable name="myDT"         select="concat($myDay, '.', $myMonth, '.', $myYear)"/>
-->
<!-- ISO -->
	<xsl:variable name="myDT"         select="concat($myYear, '-', $myMonth, '-', $myDay)"/>
<!-- -->



	<!-- ******************** Auxiliary Named Templates ******************** -->



	<!-- ******************************************************************* -->
	<!-- trap out previous version -->

	<xsl:template match="/htWeb1">
		<xsl:message terminate="yes">Fatal error: this stylesheet needs /htWeb2</xsl:message>
	</xsl:template>



	<!-- ******************************************************************* -->

	<xsl:template match="/htWeb2">
		<!-- Do DOCTYPE the hard way -->
		<xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;</xsl:text>

		<!-- copy over language attribute from html element of body.htm -->
		<html lang="{document(concat(htHomeDir, '/', htDownDir, '/', $mySrcDoc))/html/@lang}">
			<head>
				<meta charset="UTF-8"/>
				<!-- enable search engines -->
				<meta name="robots" content="index,follow"/>
				<!-- support mobile devices -->
				<meta name="viewport" content="width=device-width, initial-scale=1.0"/>

				<!-- copy over other meta stuff from body.htm, except mine and charset and viewport -->
				<!-- I might have viewport in body.htm in the future, hence this avoids duplification -->
				<xsl:copy-of select="document(concat(htHomeDir, '/', htDownDir, '/', $mySrcDoc))/html/head/meta[not( starts-with(@name, 'ht') or @charset or @name='viewport')]"/>

				<!-- global style sheet -->
				<link rel="stylesheet" type="text/css" href="{htUpDir}/{$myCSSDoc}"/>

				<!-- copy over title from body.htm -->
				<xsl:copy-of select="document(concat(htHomeDir, '/', htDownDir, '/', $mySrcDoc))/html/head/title"/>
			</head>


			<body>

				<!-- Top Banner -->
				<div id="htHeader" class="htHeaderBG">
					<a href="#htLeftWrapper"><img src="{htUpDir}/htHmbrgr.svg" id="htHmbrgr" alt="Menu"/></a>
					<img src="{htUpDir}/redetho-logo1-nbg.svg" id="htLogo" alt="redetho logo"/>
				</div>

				<!-- Main Content -->
				<div id="htMainWrapper">
<xsl:text>

</xsl:text>
					<xsl:comment> *** Begin content *** </xsl:comment>
<xsl:text>
</xsl:text>
					<xsl:copy-of select="document(concat(htHomeDir, '/', htDownDir, '/', $mySrcDoc))/html/body/node()"/>
<xsl:text>
</xsl:text>
					<xsl:comment> *** End content *** </xsl:comment>
<xsl:text>

</xsl:text>


				<!-- Footer -->
				<hr id="htFootSep"/>
				<!-- inserted zero width joiner directly using C-x 8 RET 200d RET between the "a" and "t" of (at)-->
				<p id="htFooter">Last change: <xsl:value-of select="$myDT"/><br/>&copy; 2002-<xsl:value-of select="$myTodayYear"/> Dr.&#160;Thomas Redelberger redetho(a‍t)gmx.de</p>
				</div>

<xsl:text>

</xsl:text>

				<!-- Navigation -->
				<div id="htLeftWrapper">
					<a href="./{$myDstDoc}" id="htClsrLnk"><img src="{htUpDir}/htClsr.svg" id="htClsrIcn" alt="Close menu"/></a>
					<ul class="htLeftNavUl0">
						<xsl:apply-templates select="htNode"/>
					</ul>	
				</div>


			</body>
		</html>
	</xsl:template>		<!-- end match root -->



	<!-- ******************************************************************* -->

	<!-- For each Node  -->
	<xsl:template match="htNode">

		<xsl:variable name="myImg"><xsl:choose>			<!-- navigation graphics depend on position -->
			<xsl:when test="position() = last()">Lst</xsl:when>
			<xsl:otherwise>Mid</xsl:otherwise>
		</xsl:choose></xsl:variable>

		<li class="htLeftNavLi">

			<!-- appropriate path graphics -->
			<xsl:choose>
				<!-- /home/ gets special graphics -->
				<xsl:when test="@levelNo = '1'">
					<a href="{TgtURI}/{$myDstDoc}" class="htLeftNavA">
						<img src="{/htWeb2/htUpDir}/htHome.svg" class="htNvGr" alt="Home" />
					</a>
				</xsl:when>
				<xsl:otherwise>

					<xsl:choose>		<!-- different graphics -->
						<xsl:when test="@hasChilds = 'y' and htNode">
							<a href="../{$myDstDoc}" class="htLeftNavA">
								<img src="{/htWeb2/htUpDir}/htHng{$myImg}Mi.svg" class="htNvGr" alt="Collapse"/>
							</a>
						</xsl:when>

						<xsl:when test="@hasChilds = 'y' and not(htNode)">
							<a href="{TgtURI}/{$myDstDoc}" class="htLeftNavA">
								<img src="{/htWeb2/htUpDir}/htHng{$myImg}Pl.svg" class="htNvGr" alt="Expand"/>
							</a>
						</xsl:when>

						<xsl:when test="not(@hasChilds = 'y')">
							<img src="{/htWeb2/htUpDir}/htHng{$myImg}.svg" class="htNvGr" alt=""/>
						</xsl:when>
					</xsl:choose>	<!-- different graphics -->

				</xsl:otherwise>
			</xsl:choose>	<!-- home -->


			<!-- Links. The current one gets emphasized -->
			<xsl:choose>
				<xsl:when test="@isCurrent='y'">
					<strong><em>
						<a href="{TgtURI}/{$myDstDoc}" class="htLeftNavA">
							<xsl:value-of select="TabName"/>
						</a>
					</em></strong>
				</xsl:when>
				<xsl:otherwise>
					<a href="{TgtURI}/{$myDstDoc}" class="htLeftNavA">
						<xsl:value-of select="TabName"/>
					</a>
				</xsl:otherwise>
			</xsl:choose>


			<!--recursively go down to next node(s) -->
			<xsl:if test="htNode">				<!-- avoid trailing empty list -->
				<ul class="htLeftNavUlN">
					<xsl:apply-templates select="htNode"/>
				</ul>	
			</xsl:if>

		</li>

	</xsl:template>		<!-- For each Node  -->



</xsl:stylesheet>

<!-- ************************* End of htWSite.xsl ************************** -->
